@@ -2,7 +2,8 @@ import { Button, FormGroup, MenuItem } from 'react-bootstrap';
 import { connect } from 'react-redux';
 import { defineMessages, FormattedMessage, injectIntl } from 'react-intl';
 import ImmutablePropTypes from 'react-immutable-proptypes';
-import React, { PropTypes } from 'react';
+import React from 'react';
+import PropTypes from 'prop-types';
 import { change, submit, isInvalid } from 'redux-form';
 
 import ConfirmationModal from '../../ui/ConfirmationModal';
@@ -21,8 +22,8 @@ const messages = defineMessages({
   },
   disabledButtonsWarning: {
     id: 'NodesToolbarActions.disabledButtonsWarning',
-    defaultMessage: `You need to select Nodes first or there is operation already in progress on
-                     some of the selected Nodes`
+    defaultMessage: 'You need to select Nodes first, or there is an operation already in ' +
+      'progress on some of the selected Nodes.'
   },
   introspectNodes: {
     id: 'NodesToolbarActions.introspectNodes',
@@ -38,6 +39,12 @@ const messages = defineMessages({
     description: '"Providing" the nodes changes the provisioning state to "available" so that ' +
       'they can be used in a deployment.'
   },
+  manageNodes: {
+    id: 'NodesToolbarActions.manageNodes',
+    defaultMessage: 'Manage Nodes',
+    description: '"Managing" the nodes changes the provisioning state to "manageable" so that ' +
+      'they can be introspected.'
+  },
   deleteNodes: {
     id: 'NodesToolbarActions.deleteNodes',
     defaultMessage: 'Delete Nodes'
@@ -98,14 +105,20 @@ class NodesToolbarActions extends React.Component {
           <DropdownKebab id="nodesActionsKebab" pullRight>
             <MenuItem
               disabled={this.props.disabled}
-              onClick={() => this.setState({ showTagNodesModal: true })}
+              onSelect={this.submitForm.bind(this, 'manage')}
+            >
+              <FormattedMessage {...messages.manageNodes} />
+            </MenuItem>
+            <MenuItem
+              disabled={this.props.disabled}
+              onSelect={() => this.setState({ showTagNodesModal: true })}
             >
               <FormattedMessage {...messages.tagNodes} />
             </MenuItem>
             <MenuItem
               className="bg-danger"
               disabled={this.props.disabled}
-              onClick={() => this.setState({ showDeleteModal: true })}
+              onSelect={() => this.setState({ showDeleteModal: true })}
             >
               <FormattedMessage {...messages.deleteNodes} />
             </MenuItem>
